[PATCH 04/10] fdtgrep: Correct references to fdt_find_regions()

Simon Glass sjg at chromium.org
Sun Dec 17 17:36:17 CET 2023


The function name is actually fdtgrep_find_regions() so update the name
in comments accordinging.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

 tools/fdtgrep.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/tools/fdtgrep.c b/tools/fdtgrep.c
index 41d8b41252dd..b56d2fe21c9a 100644
--- a/tools/fdtgrep.c
+++ b/tools/fdtgrep.c
@@ -576,10 +576,10 @@ static int check_type_include(void *priv, int type, const char *data, int size)
 }
 
 /**
- * h_include() - Include handler function for fdt_find_regions()
+ * h_include() - Include handler function for fdtgrep_find_regions()
  *
  * This function decides whether to include or exclude a node, property or
  * compatible string. The function is defined by fdt_find_regions().
  *
  * The algorithm is documented in the code - disp->invert is 0 for normal
  * operation, and 1 to invert the sense of all matches.
@@ -822,7 +822,7 @@ static int do_fdtgrep(struct display_info *disp, const char *filename)
 				region, max_regions, path, sizeof(path),
 				disp->flags);
 		if (count < 0) {
-			report_error("fdt_find_regions", count);
+			report_error("fdtgrep_find_regions", count);
 			free(region);
 			return -1;
 		}
@@ -576,10 +576,10 @@ static int check_type_include(void *priv, int type, const char *data, int size)
  *
  * This function decides whether to include or exclude a node, property or
- * compatible string. The function is defined by fdt_find_regions().
+ * compatible string. The function is defined by fdtgrep_find_regions().
  *
  * The algorithm is documented in the code - disp->invert is 0 for normal
-- 
2.43.0.472.g3155946c3a-goog



More information about the U-Boot mailing list